@@ -1,4 +1,3 @@
 from .core import RomanStep, RomanPipeline
 
-
-__all__ = ["RomanStep", "RomanPipeline"]
+__all__ = ["RomanPipeline", "RomanStep"]
