@@ -21,7 +21,13 @@ def get_steps():
     # class definitions.  We need to avoid importing romancal.pipeline and
     # romancal.step to keep the CLI snappy.
     return [
+        ("romancal.pipeline.ExposurePipeline", 'roman_elp', True),
         ("romancal.step.DarkCurrentStep", None, False),
         ("romancal.step.DQInitStep", None, False),
         ("romancal.step.FlatFieldStep", None, False),
+        ("romancal.step.JumpStep", None, False),
+        ("romancal.step.LinearityStep", None, False),
+        ("romancal.step.RampFitStep", None, False),
+        ("romancal.step.SaturationStep", None, False),
+        ("romancal.step.AssignWcsStep", None, False),
     ]
